pub struct BasicInfo<UrlT = Url> {
pub handles: Handles,
pub name: String,
pub description: String,
pub url: UrlT,
pub id: Id,
}Expand description
Basic public details about hub, as provided by PubHubs Central.
Fields
handles: HandlesThe handles for this hub, using in URLs and other places to be understood by both human and machine. The first one is the one that’s used by default. WARNING: Handles may be added, but should not be removed.
name: StringHuman-readable short name for this hub
description: StringShort description for this hub. This is stored centrally to facilitate searching. May be changed freely.
url: UrlTHub client API url, likely of the form https://<some domain>/_synapse/client/.
Must end with a /. Can be changed freely.
id: IdImmutable and unique identifier